@@ -1,4 +1,5 @@
 # flake8: noqa
+import logging
 
 from hammurabi.config import config
 from hammurabi.law import Law
@@ -11,11 +12,11 @@ from hammurabi.preconditions.attributes import (
     IsOwnedBy,
 )
 from hammurabi.preconditions.base import Precondition
-from hammurabi.preconditions.directories import IsDirectoryExists, IsDirectoryNotExists
-from hammurabi.preconditions.files import IsFileExists, IsFileNotExists
-from hammurabi.preconditions.text import IsLineExists, IsLineNotExists
+from hammurabi.preconditions.directories import IsDirectoryExist, IsDirectoryNotExist
+from hammurabi.preconditions.files import IsFileExist, IsFileNotExist
+from hammurabi.preconditions.text import IsLineExist, IsLineNotExist
 from hammurabi.reporters.base import Reporter
-from hammurabi.reporters.json import JSONReporter
+from hammurabi.reporters.json import JsonReporter
 from hammurabi.rules.attributes import ModeChanged, OwnerChanged
 from hammurabi.rules.base import Rule
 from hammurabi.rules.directories import (
@@ -31,20 +32,27 @@ from hammurabi.rules.files import (
     FilesNotExist,
 )
 from hammurabi.rules.json import (
-    JSONKeyExists,
-    JSONKeyNotExists,
-    JSONKeyRenamed,
-    JSONValueExists,
-    JSONValueNotExists,
+    JsonKeyExists,
+    JsonKeyNotExists,
+    JsonKeyRenamed,
+    JsonValueExists,
+    JsonValueNotExists,
 )
 from hammurabi.rules.operations import Copied, Moved, Renamed
 from hammurabi.rules.templates import TemplateRendered
 from hammurabi.rules.text import LineExists, LineNotExists, LineReplaced
+from hammurabi.rules.toml import (
+    TomlKeyExists,
+    TomlKeyNotExists,
+    TomlKeyRenamed,
+    TomlValueExists,
+    TomlValueNotExists,
+)
 
 try:
     from hammurabi.notifications.slack import SlackNotification
 except ImportError:
-    pass
+    logging.debug("import of slack notification is skipped")
 
 
 try:
@@ -57,18 +65,18 @@ try:
         SectionRenamed,
     )
 except ImportError:
-    pass
+    logging.debug("import of ini file based rules is skipped")
 
 
 try:
     from hammurabi.rules.yaml import (
-        YAMLKeyExists,
-        YAMLKeyNotExists,
-        YAMLKeyRenamed,
-        YAMLValueExists,
-        YAMLValueNotExists,
+        YamlKeyExists,
+        YamlKeyNotExists,
+        YamlKeyRenamed,
+        YamlValueExists,
+        YamlValueNotExists,
     )
 except ImportError:
-    pass
+    logging.debug("import of yaml file based rules is skipped")
 
-__version__ = "0.10.0"
+__version__ = "0.11.0"
